nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Bootadr

Struct Bootadr 

#[repr(transparent)]
pub struct Bootadr(pub u32);
Boot Address

Tuple Fields

0: u32

Implementations

Source

impl Bootadr

pub const fn addr(&self) -> u32

32-bit boot address, the boot address should be 4-byte aligned.

pub const fn set_addr(&mut self, val: u32)

32-bit boot address, the boot address should be 4-byte aligned.